--- traceplot.cpp.orig	2020-05-21 09:59:50 UTC
+++ traceplot.cpp
@@ -20,6 +20,7 @@
 #include <QPixmapCache>
 #include <QTextStream>
 #include <QtConcurrent>
+#include <QPainterPath>
 #include "samplesource.h"
 #include "traceplot.h"
 
