--- src/libslic3r/PrintObject.cpp.orig	2021-07-16 10:14:03 UTC
+++ src/libslic3r/PrintObject.cpp
@@ -19,7 +19,6 @@
 #include <float.h>
 
 #include <tbb/parallel_for.h>
-#include <tbb/atomic.h>
 
 #include <Shiny/Shiny.h>
 
